is-even
=======

|Tests| |PyPI| |PyPI - Downloads|

   Return true if the given number is even

Install
-------

Install with `pip <https://pypi.org/project/pip/>`__

::

   pip install is-even

Usage
-----

.. code:: python

   from is_even import is_even

   is_even(0)
   # => False
   is_even(1)
   # => True
   is_even(2)
   # => False
   is_even(3)
   # => True

.. |Tests| image:: https://github.com/victorbnl/is-even/actions/workflows/tests.yml/badge.svg?branch=main
   :target: https://github.com/victorbnl/is-even/actions/workflows/tests.yml
.. |PyPI| image:: https://img.shields.io/pypi/v/is-even
   :target: https://pypi.org/project/is-even/
.. |PyPI - Downloads| image:: https://img.shields.io/pypi/dm/is-even
   :target: https://pypi.org/project/is-even/
